import logging
from client import EvernetClient
from query import listing_query, photo_query
from parser import parse

logger = logging.getLogger(__name__)


def execute_listing_query(username, password, endpoint, params, filter=""):
    client = EvernetClient(endpoint)
    query = listing_query(username, password, params, filter)
    logger.info('Executing query %s with params %s...' % (endpoint, params))
    data = client.listing_query(query)
    logger.info('got results')
    return parse(data)


def execute_photo_query(username, password, listing_number):
    client = EvernetClient('RetrieveImages')
    query = photo_query(username, password, listing_number)
    logger.info('Executing photo query for listing number %s' % listing_number)
    data = client.photo_query(query)
    logger.info('got results')
    return parse(data)



from xml.etree.ElementTree import iterparse

SCHEMA_1_2_TYPES = [
    'BusinessOpportunity',
    'CommercialIndustrial',
    'FarmRanch',
    'Manufactured',
    'MultiFamily',
    'TimeShare',
    'VacantLand',
    'Condominium',
    'Residential',
]


TAGS_I_CARE_ABOUT = [
    '{http://www.nwmls.com/Schemas/General/EverNetAmenityXML.xsd}Amenity',
    '{http://www.nwmls.com/Schemas/General/EverNetOfficeXML.xsd}office',
    '{NWMLS:EverNet:ImageData:1.0}Image',
] + ['{http://www.nwmls.com/Schemas/Standard/StandardXML1_2.xsd}' + t for t in SCHEMA_1_2_TYPES]


def parse(data):
    for event, elem in iterparse(data):
        if elem.tag in TAGS_I_CARE_ABOUT:
            yield elem
            elem.clear()



import itertools

def iterate_criteria(begin_date, end_date, property_types=None, areas=None, cities=None, status=None):
    base_criteria = {
        'MLS': 'nwmls',
        'BeginDate': begin_date,
        'EndDate': end_date,
        'EndDate': end_date,
    }
    if not cities and not areas and not property_types:
        yield base_criteria
    else:
        areas = areas or [None]
        cities = cities or [None]
        property_types = property_types or [None]
        for property_type, area, city in itertools.product(property_types, areas, cities):
            criteria = {}
            if area:
                criteria['Area'] = area
            if city:
                criteria['City'] = city
            if status:
                criteria['Status'] = status
            if property_type:
                criteria['PropertyType'] = property_type
            criteria.update(base_criteria)
            yield criteria
